@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- # Lint as: python3
-# Copyright 2020 Google LLC. All Rights Reserved.
+# Copyright 2021 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,11 +31,14 @@ _EntityNames = collections.namedtuple(
     "singular plural docs_name valid_pattern secondary_description")
 
 _ENTITY_TUPLES = [
-    _EntityNames("organization", "organizations", "organization",
-                 r"^[a-z][-a-z0-9]{0,30}[a-z0-9]$",
-                 "Apigee organization containing the {resource}. If "
-                 "unspecified, the Cloud Platform project's associated "
-                 "organization will be used."),
+    _EntityNames("project", "projects", "projects", None,
+                 "GCP project containing the {resource}."),
+    _EntityNames(
+        "organization", "organizations", "organization",
+        r"^[a-z][-a-z0-9]{0,30}[a-z0-9]$",
+        "Apigee organization containing the {resource}. If "
+        "unspecified, the Cloud Platform project's associated "
+        "organization will be used."),
     _EntityNames("api", "apis", "API proxy", r"^[\s\w.-]{1,255}$",
                  "API proxy for the {resource}."),
     _EntityNames("environment", "environments", "environment",
@@ -54,6 +57,9 @@ _ENTITY_TUPLES = [
                  "Developer of the {resource}."),
     _EntityNames("app", "apps", "application", None,
                  "Relevant application for the {resource}."),
+    _EntityNames("archiveDeployment", "archiveDeployments",
+                 "archive deployment", None,
+                 "Archive deployment for {resource}")
 ]
 ENTITIES = {item.singular: item for item in _ENTITY_TUPLES}
 
