@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Flags and helpers for the compute security policies rules commands."""
+
 from __future__ import absolute_import
 from __future__ import division
-
 from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 
@@ -58,11 +59,16 @@ def AddMatcher(parser, required=True):
       help='The Cloud Armor rules language expression to match for this rule.')
 
 
-def AddAction(parser, required=True):
+def AddAction(parser, required=True, support_redirect=False):
   """Adds the action argument to the argparse."""
+  actions = [
+      'allow', 'deny-403', 'deny-404', 'deny-502', 'redirect-to-recaptcha'
+  ]
+  if support_redirect:
+    actions.append('redirect')
   parser.add_argument(
       '--action',
-      choices=['allow', 'deny-403', 'deny-404', 'deny-502'],
+      choices=actions,
       type=lambda x: x.lower(),
       required=required,
       help='The action to take if the request matches the match condition.')
@@ -82,3 +88,11 @@ def AddPreview(parser, default):
       action='store_true',
       default=default,
       help='If specified, the action will not be enforced.')
+
+
+def AddRedirectTarget(parser):
+  """Adds redirect-target argument to the argparse."""
+  parser.add_argument(
+      '--redirect-target',
+      help='The URL to which traffic is routed when the rule action is set to "redirect".'
+  )
