@@ -36,7 +36,9 @@ class Create(base.CreateCommand):
   """
 
   BACKEND_BUCKET_ARG = None
-  _support_flexible_cache_step_one = False
+  _support_flexible_cache_step_one = True
+  _support_flexible_cache_step_two = False
+  _support_negative_cache = False
 
   @classmethod
   def Args(cls, parser):
@@ -50,6 +52,11 @@ class Create(base.CreateCommand):
 
     if cls._support_flexible_cache_step_one:
       cdn_flags.AddFlexibleCacheStepOne(parser, 'backend bucket')
+    if cls._support_negative_cache:
+      cdn_flags.AddNegativeCache(parser, 'backend bucket')
+
+    if cls._support_flexible_cache_step_two:
+      cdn_flags.AddFlexibleCacheStepTwo(parser, 'backend bucket')
 
   def CreateBackendBucket(self, args):
     """Creates and returns the backend bucket."""
@@ -67,15 +74,20 @@ class Create(base.CreateCommand):
         bucketName=args.gcs_bucket_name,
         enableCdn=enable_cdn)
 
-    if self._support_flexible_cache_step_one \
-        and args.custom_response_header is not None:
-      backend_bucket.customResponseHeaders = args.custom_response_header
-
     backend_buckets_utils.ApplyCdnPolicyArgs(
         client,
         args,
         backend_bucket,
-        support_flexible_cache_step_one=self._support_flexible_cache_step_one)
+        support_flexible_cache_step_one=self._support_flexible_cache_step_one,
+        support_flexible_cache_step_two=self._support_flexible_cache_step_two,
+        support_negative_cache=self._support_negative_cache)
+
+    if self._support_flexible_cache_step_one:
+      if args.custom_response_header is not None:
+        backend_bucket.customResponseHeaders = args.custom_response_header
+      if (backend_bucket.cdnPolicy is not None and
+          backend_bucket.cdnPolicy.cacheMode and args.enable_cdn is not False):  # pylint: disable=g-bool-id-comparison
+        backend_bucket.enableCdn = True
 
     return backend_bucket
 
@@ -104,3 +116,5 @@ class CreateAlphaBeta(Create):
   maps define which requests are sent to which backend buckets.
   """
   _support_flexible_cache_step_one = True
+  _support_negative_cache = True
+  _support_flexible_cache_step_two = True
