@@ -24,6 +24,7 @@ from surface.container.clusters import create
 # Select which flags are auto flags
 auto_flags = [
     'args',
+    'clusterversion',
     'ipalias_additional',
     'masterauth',
     'nodeidentity',
@@ -34,11 +35,9 @@ auto_flags = [
 # Change default flag values in create-auto
 flag_overrides = {
     'num_nodes': 1,
-    'enable_private_nodes': True,
     'enable_ip_alias': True,
     'enable_master_authorized_networks': False,
     'privatecluster': {
-        'enable_private_nodes': None,
         'private_cluster': None,
     },
 }
@@ -47,10 +46,21 @@ auto_flag_defaults = dict(list(create.base_flag_defaults.items()) + \
                           list(flag_overrides.items()))
 
 
+@base.Hidden
+@base.ReleaseTracks(base.ReleaseTrack.GA)
+class Create(create.Create):
+  autopilot = True
+  default_flag_values = auto_flag_defaults
+
+  @staticmethod
+  def Args(parser):
+    create.AddFlags(create.GA, parser, auto_flag_defaults, auto_flags)
+
+
 @base.Hidden
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
 class CreateBeta(create.CreateBeta):
-  autogke = True
+  autopilot = True
   default_flag_values = auto_flag_defaults
 
   @staticmethod
@@ -61,7 +71,7 @@ class CreateBeta(create.CreateBeta):
 @base.Hidden
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(create.CreateAlpha):
-  autogke = True
+  autopilot = True
   default_flag_values = auto_flag_defaults
 
   @staticmethod
