@@ -18,7 +18,9 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import os
 import textwrap
+from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.util import apis as core_apis
 from googlecloudsdk.command_lib.container.hub.features import base
 from googlecloudsdk.core import exceptions
@@ -46,6 +48,7 @@ class Apply(base.UpdateCommand):
 
   FEATURE_NAME = 'configmanagement'
   FEATURE_DISPLAY_NAME = 'Config Management'
+  LATEST_VERSION = '1.5.2'
 
   @classmethod
   def Args(cls, parser):
@@ -97,6 +100,7 @@ class Apply(base.UpdateCommand):
     applied_config = msg.ConfigManagementFeatureSpec.MembershipConfigsValue.AdditionalProperty(
         key=membership,
         value=msg.MembershipConfig(
+            version=self._get_backfill_version(membership),
             configSync=config_sync,
             policyController=policy_controller))
     # UpdateFeature uses patch method to update membership_configs map,
@@ -108,6 +112,62 @@ class Apply(base.UpdateCommand):
         configmanagementFeatureSpec=msg.ConfigManagementFeatureSpec(
             membershipConfigs=m_configs))
 
+  def _get_backfill_version(self, mem):
+    """Determines what the version field in FeatureSpec should be set to.
+
+    Args:
+      mem: The membership name whose Spec will be backfilled.
+
+    Returns:
+      version: A string denoting the version field in MembershipConfig
+    Raises: Error, if retrieving FeatureSpec of FeatureState fails
+    """
+    try:
+      project_id = properties.VALUES.core.project.GetOrFail()
+      name = 'projects/{0}/locations/global/features/{1}'.format(
+          project_id, self.FEATURE_NAME)
+      response = base.GetFeature(name)
+    except apitools_exceptions.HttpUnauthorizedError as e:
+      raise exceptions.Error(
+          'You are not authorized to see the status of {} '
+          'Feature from project [{}]. Underlying error: {}'.format(
+              self.FEATURE_DISPLAY_NAME, project_id, e))
+    except apitools_exceptions.HttpNotFoundError as e:
+      raise exceptions.Error(
+          '{} Feature for project [{}] is not enabled'.format(
+              self.FEATURE_DISPLAY_NAME, project_id))
+
+    # First check FeatureSpec to see if an existing version is set
+    mem_config = _parse_membership(response, mem)
+    if mem_config and mem_config.version:
+      return mem_config.version
+
+    # Next, check FeatureState
+    if response.featureState and response.featureState.detailsByMembership:
+      membership_details = response.featureState.detailsByMembership.additionalProperties
+      for m in membership_details:
+        if os.path.basename(m.key) == mem:
+          fs = m.value.configmanagementFeatureState
+          if fs and fs.membershipConfig and fs.membershipConfig.version:
+            # If the version on the cluster is later than the latest supported
+            # version in the Hub API, we do not want to write this version to
+            # spec. If we did, this would result in an error updating spec,
+            # rendering this gcloud command unusable.
+            return fs.membershipConfig.version \
+              if fs.membershipConfig.version <= self.LATEST_VERSION else ''
+
+    # If Spec/State did not contain version, return default (latest version)
+    return self.LATEST_VERSION
+
+
+def _parse_membership(response, mem):
+  if response.configmanagementFeatureSpec is None or response.configmanagementFeatureSpec.membershipConfigs is None:
+    return None
+
+  for details in response.configmanagementFeatureSpec.membershipConfigs.additionalProperties:
+    if details.key == mem:
+      return details.value
+
 
 def _validate_meta(configmanagement):
   """Validate the parsed configmanagement yaml.
@@ -116,7 +176,7 @@ def _validate_meta(configmanagement):
     configmanagement: The dict loaded from yaml.
   """
   if not isinstance(configmanagement, dict):
-    raise exceptions.Error('Invalid Configmanagement template.')
+    raise exceptions.Error('Invalid ConfigManagement template.')
   if ('apiVersion' not in configmanagement or
       configmanagement['apiVersion'] != 'configmanagement.gke.io/v1'):
     raise exceptions.Error(
@@ -124,10 +184,29 @@ def _validate_meta(configmanagement):
   if ('kind' not in configmanagement or
       configmanagement['kind'] != 'ConfigManagement'):
     raise exceptions.Error('Only support "kind: ConfigManagement"')
-  for field in configmanagement['spec']:
-    if field not in ['git', 'policyController']:
+  if 'spec' not in configmanagement:
+    raise exceptions.Error('Missing required field .spec')
+  spec = configmanagement['spec']
+  for field in spec:
+    if field not in ['git', 'policyController', 'sourceFormat']:
       raise exceptions.Error(
           'Please remove illegal field .spec.{}'.format(field))
+  if 'sourceFormat' in spec and configmanagement['spec'][
+      'sourceFormat'] not in ['hierarchy', 'unstructured']:
+    raise exceptions.Error('Please remove illegal value of .spec.sourceFormat')
+  if 'git' in spec:
+    for field in spec['git']:
+      if field not in [
+          'policyDir', 'proxy', 'secretType', 'syncBranch', 'syncRepo',
+          'syncRev', 'syncWait'
+      ]:
+        raise exceptions.Error(
+            'Please remove illegal field .spec.git.{}'.format(field))
+    if 'proxy' in spec['git']:
+      for field in spec['git']['proxy']:
+        if field not in ['httpsProxy']:
+          raise exceptions.Error(
+              'Please remove illegal field .spec.git.proxy.{}'.format(field))
 
 
 def _parse_config_sync(configmanagement, msg):
@@ -160,7 +239,11 @@ def _parse_config_sync(configmanagement, msg):
       setattr(git_config, field, spec_git[field])
   if 'syncWait' in spec_git:
     git_config.syncWaitSecs = spec_git['syncWait']
+  if 'proxy' in spec_git and 'httpsProxy' in spec_git['proxy']:
+    git_config.httpsProxy = spec_git['proxy']['httpsProxy']
 
+  if 'sourceFormat' in configmanagement['spec']:
+    config_sync.sourceFormat = configmanagement['spec']['sourceFormat']
   return config_sync
 
 
@@ -184,6 +267,11 @@ def _parse_policy_controller(configmanagement, msg):
     return None
 
   spec_policy_controller = configmanagement['spec']['policyController']
+  # Required field
+  if configmanagement['spec'][
+      'policyController'] is None or 'enabled' not in spec_policy_controller:
+    raise exceptions.Error(
+        'Missing required field .spec.policyController.enabled')
   enabled = spec_policy_controller['enabled']
   if not isinstance(enabled, bool):
     raise exceptions.Error(
@@ -196,13 +284,15 @@ def _parse_policy_controller(configmanagement, msg):
 
   policy_controller = msg.PolicyController(enabled=True)
   # When the policyController is set to be enabled, policy_controller will
-  # be filled with the valid fieleds set in spec_policy_controller, which
+  # be filled with the valid fields set in spec_policy_controller, which
   # were mapped from the config-management.yaml
-  for field in [
-      'templateLibraryInstalled', 'auditIntervalSeconds',
-      'referentialRulesEnabled', 'exemptableNamespaces'
-  ]:
-    if field in spec_policy_controller:
-      setattr(policy_controller, field, spec_policy_controller[field])
+  for field in spec_policy_controller:
+    if field not in [
+        'enabled', 'templateLibraryInstalled', 'auditIntervalSeconds',
+        'referentialRulesEnabled', 'exemptableNamespaces'
+    ]:
+      raise exceptions.Error(
+          'Please remove illegal field .spec.policyController.{}'.format(field))
+    setattr(policy_controller, field, spec_policy_controller[field])
 
   return policy_controller
