@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import re
+
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import walker_util
 from googlecloudsdk.command_lib.meta import help_util
@@ -70,6 +72,13 @@ class GenerateHelpDocs(base.Command):
               'your browser at [](http://localhost:8888) to view the manpage '
               'tree. If not specified then the HTML manpage site will not be '
               'generated.'))
+    parser.add_argument(
+        '--linter-dir',
+        metavar='DIRECTORY',
+        help=('The directory where the generated documentation linter errors '
+              'for the help text reference document subtree will be written. '
+              'If not specified then documentation linter documents will not '
+              'be generated.'))
     parser.add_argument(
         '--manpage-dir',
         metavar='DIRECTORY',
@@ -106,15 +115,16 @@ class GenerateHelpDocs(base.Command):
   def Run(self, args):
     out_of_date = set()
 
-    def Generate(kind, generator, directory, encoding='utf8', hidden=False):
+    def Generate(kind, generator, directory, encoding='utf-8', hidden=False):
       """Runs generator and optionally updates help docs in directory."""
+      restrict_dir = [re.sub(r'_', r'-', p) for p in args.restrict]
       console_attr.ResetConsoleAttr(encoding)
       if not args.update:
         generator(self._cli_power_users_only, directory).Walk(
-            hidden, args.restrict)
+            hidden, restrict_dir)
       elif help_util.HelpUpdater(
           self._cli_power_users_only, directory, generator,
-          test=args.test, hidden=hidden).Update(args.restrict):
+          test=args.test, hidden=hidden).Update(restrict_dir):
         out_of_date.add(kind)
 
     # Handle deprecated flags -- probably burned in a bunch of eng scripts.
@@ -140,6 +150,9 @@ class GenerateHelpDocs(base.Command):
     if args.manpage_dir:
       Generate('man page', walker_util.ManPageGenerator, args.manpage_dir,
                hidden=args.hidden)
+    if args.linter_dir:
+      Generate('command linter', walker_util.LinterGenerator, args.linter_dir,
+               hidden=args.hidden)
 
     # Test update fails with an exception if documents are out of date.
 
